Learn R Programming

cartography (version 2.1.0)

cartography: Cartography Package

Description

Create and integrate maps in your R workflow. This package allows various cartographic representations such as proportional symbols, choropleth, typology, flows or discontinuities maps. It also offers several features enhancing the graphic presentation of maps like cartographic palettes, layout elements (scale, north arrow, title...), labels, legends or access to some cartographic APIs.

A vignette contains commented scripts on how to build various types of maps with cartography: vignette(topic = "cartography")

Main functions :

Arguments